==> intel-cmt-cat_3.0.0.orig.tar.xz: intel-cmt-cat-3.0.0/pqos/profiles.h <==
/*
 * BSD LICENSE
 *
 * Copyright(c) 2014-2019 Intel Corporation. All rights reserved.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *   * Neither the name of Intel Corporation nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * Allocation profiles API
 */

#include <stdint.h>
#include <stdio.h>
#include "pqos.h"

#ifndef __PROFILES_H__
#define __PROFILES_H__

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief Prints list of supported L3CA profiles to STDOUT
 *
 * @param [in] fp file stream to write profile descriptions to
 */
void profile_l3ca_list(FILE *fp);

/**
 * @brief Applies selected profile via selfn_allocation_class()
 *
 * @param [in] name of the profile
 * @param [in] l3ca L3CA capability structure
 *
 * @return Operations status
 * @retval 0 OK
 * @retval -1 error
 */
int profile_l3ca_apply(const char *name,
                       const struct pqos_capability *cap_l3ca);


#ifdef __cplusplus
}
#endif

#endif /* __PROFILES_H__ */

==> intel-cmt-cat_3.2.orig.tar.xz: intel-cmt-cat-3.2/pqos/profiles.h <==
/*
 * BSD LICENSE
 *
 * Copyright(c) 2014-2019 Intel Corporation. All rights reserved.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *   * Neither the name of Intel Corporation nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * Allocation profiles API
 */

#include <stdint.h>
#include <stdio.h>
#include "pqos.h"

#ifndef __PROFILES_H__
#define __PROFILES_H__

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief Prints list of supported L3CA profiles to STDOUT
 */
void profile_l3ca_list(void);

/**
 * @brief Applies selected profile via selfn_allocation_class()
 *
 * @param [in] name of the profile
 * @param [in] l3ca L3CA capability structure
 *
 * @return Operations status
 * @retval 0 OK
 * @retval -1 error
 */
int profile_l3ca_apply(const char *name,
                       const struct pqos_capability *cap_l3ca);


#ifdef __cplusplus
}
#endif

#endif /* __PROFILES_H__ */
